import { h } from 'preact';
import ms from 'milliseconds';
const currentYear = new Date().getFullYear();

const getUpdatedText = updatedDate => {
  if (Date.now() - updatedDate < ms.weeks(2)) {
    const date = new Date(updatedDate);
    return `${date.getMonth() + 1}/${date.getDate()}/${(date.getFullYear() + '').slice(2)}`;
  }
};

const linkClasses = 'link f6 gray no-underline underline-hover';

export const Footer = ({
  privacyUrl = 'https://legal.anesthesiacharting.com/privacy',
  termsUrl = 'https://legal.anesthesiacharting.com/terms',
  version,
  privacyUpdatedDate,
  hideLinks
}) => {
  const updateText = privacyUpdatedDate && getUpdatedText(privacyUpdatedDate);
  return h(
    'footer',
    { className: 'pt2 pb3 tc f6 gray mb7' },
    '\xA9 ',
    currentYear,
    ' I.V. Enterprises LLC ',
    version && `v${version}`,
    ' ',
    !hideLinks && h(
      'div',
      { className: 'mt1 no-print' },
      h(
        'a',
        { className: linkClasses, href: termsUrl, rel: 'noopener' },
        'terms'
      ),
      ' | ',
      h(
        'a',
        { className: linkClasses, href: privacyUrl, rel: 'noopener' },
        'privacy'
      ),
      updateText && ` (updated ${updateText})`
    )
  );
};