import { h, Component } from 'preact';
import * as sections from './sections';
import { DrawerLink, DrawerLinkContainer } from '../drawer';
import { Page } from '../crate';
import { AppLayout } from '../app-layout';
import { version } from '../../package.json';
import { LogoLightMark } from '../logo';
import { TapIconButton } from '../button';

export default class extends Component {
  constructor(props) {
    super(props);
    this.state = {
      screenIsWide: this.isScreenWide(),
      drawerOpen: false,
      drawerEnabled: true
    };
    this.toggleDrawerOpen = this.toggleDrawerOpen.bind(this);
    this.toggleDrawerEnabled = this.toggleDrawerEnabled.bind(this);
    this.handleResize = this.handleResize.bind(this);
  }

  componentDidMount() {
    window.addEventListener('resize', this.handleResize, { passive: true });
  }

  componentWillUnmount() {
    window.removeEventListener('resize', this.handleResize, { passive: true });
  }

  toggleDrawerOpen() {
    this.setState({ drawerOpen: !this.state.drawerOpen });
  }

  toggleDrawerEnabled() {
    this.setState({ drawerEnabled: !this.state.drawerEnabled });
  }

  handleResize() {
    const isWide = this.isScreenWide();
    if (isWide !== this.state.screenIsWide) {
      this.setState({ screenIsWide: isWide });
    }
  }

  isScreenWide() {
    return window.innerWidth > 960;
  }

  render(_, { screenIsWide, drawerEnabled, drawerOpen }) {
    return h(AppLayout, {
      version: version,
      doCloseDrawer: this.toggleDrawerOpen,
      doOpenDrawer: this.toggleDrawerOpen,
      screenIsWide: screenIsWide,
      drawerEnabled: drawerEnabled,
      drawerOpen: drawerOpen,
      mainContent: h(
        Page,
        { className: 'ph3' },
        Object.keys(sections).map(section => {
          const Component = sections[section];
          return h(
            'div',
            { id: section },
            h(Component, { key: section })
          );
        })
      ),
      statusBarContent: h(
        'div',
        { className: 'pa2 flex items-center' },
        h(TapIconButton, {
          icon: 'menu',
          onClick: this.toggleDrawerOpen,
          className: 'dn-l'
        }),
        h(LogoLightMark, { className: 'dn-l ml2', style: { width: '30px' } }),
        h(
          'h2',
          { className: 'pv0 mv2 f4 ml2' },
          'Pattern Library'
        )
      ),
      drawerContent: h(
        'div',
        null,
        h(
          DrawerLinkContainer,
          { title: 'Components' },
          Object.keys(sections).map(section => h(DrawerLink, {
            icon: 'polymer',
            href: `#${section}`,
            onClick: this.toggleDrawerOpen,
            title: section
          }))
        )
      )
    });
  }
}