import { h } from 'preact';
import cn from 'classnames';
import omit from './omit';

const alwaysPassThroughProps = ['disabled'];

export default (args => {
  const {
    tagName = 'div',
    baseClasses = '',
    options = {},
    style,
    fn,
    passThroughProps = [],
    defaultProps,
    renderChildren
  } = args;

  const allOptionValues = Object.keys(options).reduce((result, key) => {
    result.push(...options[key]);
    return result;
  }, []);

  const propsToRemove = [...allOptionValues.filter(key => !passThroughProps.includes(key) && !alwaysPassThroughProps.includes(key)), 'className', 'tagName'];

  const componentFn = incomingProps => {
    const props = Object.assign({}, defaultProps, incomingProps);
    const finalTagName = props.tagName || tagName;
    const passThroughProps = omit(props, propsToRemove);
    const className = cn(baseClasses, fn && fn(props), props.className);
    const combinedStyle = Object.assign({}, style, props.style);
    const renderedChildren = renderChildren ? renderChildren(props) : props.children;

    return h(finalTagName, Object.assign({ className, style: combinedStyle }, passThroughProps), ...renderedChildren);
  };

  componentFn.definition = args;

  return componentFn;
});